@@ -7,9 +7,12 @@ oneTimeSetUp() {
     rm -rf "$WORKON_HOME"
     mkdir -p "$WORKON_HOME"
     source "$test_dir/../virtualenvwrapper.sh"
-    mkvirtualenv "env1" >/dev/null 2>&1
-    mkvirtualenv "env2" >/dev/null 2>&1
-    deactivate >/dev/null 2>&1 
+    mkvirtualenv "test1" >/dev/null 2>&1
+    mkvirtualenv "test2" >/dev/null 2>&1
+    # Only test with leading and internal spaces. Directory names with trailing spaces are legal,
+    # and work with virtualenv on OSX, but error out on Linux.
+    mkvirtualenv " env with space" >/dev/null 2>&1
+    deactivate >/dev/null 2>&1
 }
 
 oneTimeTearDown() {
@@ -26,9 +29,9 @@ tearDown () {
 }
 
 test_workon () {
-    workon env1
+    workon test1
     assertTrue virtualenvwrapper_verify_active_environment
-    assertSame "env1" $(basename "$VIRTUAL_ENV")
+    assertSame "test1" $(basename "$VIRTUAL_ENV")
 }
 
 test_workon_activate_hooks () {
@@ -38,15 +41,15 @@ test_workon_activate_hooks () {
         echo "echo GLOBAL ${t}activate >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/${t}activate"
         chmod +x "$WORKON_HOME/${t}activate"
 
-        echo "#!/bin/sh" > "$WORKON_HOME/env2/bin/${t}activate"
-        echo "echo ENV ${t}activate >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/env1/bin/${t}activate"
-        chmod +x "$WORKON_HOME/env1/bin/${t}activate"
+        echo "#!/bin/sh" > "$WORKON_HOME/test2/bin/${t}activate"
+        echo "echo ENV ${t}activate >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/test1/bin/${t}activate"
+        chmod +x "$WORKON_HOME/test1/bin/${t}activate"
     done
 
     rm -f "$TMPDIR/catch_output"
     touch "$TMPDIR/catch_output"
 
-    workon env1
+    workon test1
     
     output=$(cat "$TMPDIR/catch_output")
     expected="GLOBAL preactivate
@@ -58,27 +61,29 @@ ENV postactivate"
     
     for t in pre post
     do
-        rm -f "$WORKON_HOME/env1/bin/${t}activate"
+        rm -f "$WORKON_HOME/test1/bin/${t}activate"
         rm -f "$WORKON_HOME/${t}activate"
     done
 }
 
 test_virtualenvwrapper_show_workon_options () {
     mkdir "$WORKON_HOME/not_env"
-    (cd "$WORKON_HOME"; ln -s env1 link_env)
+    (cd "$WORKON_HOME"; ln -s test1 link_env)
     envs=$(virtualenvwrapper_show_workon_options | tr '\n' ' ')
-    assertSame "env1 env2 link_env " "$envs"
+    # On OSX there are two trailing spaces, on Linux one, so compare substring
+    assertSame " env with space link_env test1 test2 " "${envs:0:37}"
     rmdir "$WORKON_HOME/not_env"
     rm -f "$WORKON_HOME/link_env"
 }
 
 test_virtualenvwrapper_show_workon_options_grep_options () {
     mkdir "$WORKON_HOME/not_env"
-    (cd "$WORKON_HOME"; ln -s env1 link_env)
+    (cd "$WORKON_HOME"; ln -s test1 link_env)
     export GREP_OPTIONS="--count"
     envs=$(virtualenvwrapper_show_workon_options | tr '\n' ' ')
     unset GREP_OPTIONS
-    assertSame "env1 env2 link_env " "$envs"
+    # On OSX there are two trailing spaces, on Linux one, so compare substring
+    assertSame " env with space link_env test1 test2 " "${envs:0:37}"
     rmdir "$WORKON_HOME/not_env"
     rm -f "$WORKON_HOME/link_env"
 }
@@ -94,7 +99,8 @@ test_virtualenvwrapper_show_workon_options_chpwd () {
     }
     mkdir "$WORKON_HOME/not_env"
     envs=$(virtualenvwrapper_show_workon_options | tr '\n' ' ')
-    assertSame "env1 env2 " "$envs"
+    # On OSX there are two trailing spaces, on Linux one, so compare substring
+    assertSame " env with space test1 test2 " "${envs:0:28}"
     rmdir "$WORKON_HOME/not_env"
     rm -f "$WORKON_HOME/link_env"
 }
@@ -102,7 +108,8 @@ test_virtualenvwrapper_show_workon_options_chpwd () {
 test_virtualenvwrapper_show_workon_options_no_envs () {
     old_home="$WORKON_HOME"
     export WORKON_HOME=${TMPDIR:-/tmp}/$$
-    envs=$(virtualenvwrapper_show_workon_options 2>/dev/null | tr '\n' ' ')
+    # On OSX there is a space and on Linux there is not, so strip all spaces
+    envs=$(virtualenvwrapper_show_workon_options 2>/dev/null | sed 's/\n //g')
     assertSame "" "$envs"
     export WORKON_HOME="$old_home"
 }
@@ -116,4 +123,26 @@ test_no_workon_home () {
     WORKON_HOME="$old_home"
 }
 
+test_workon_dot () {
+    cd $WORKON_HOME/test1
+    workon .
+    assertTrue virtualenvwrapper_verify_active_environment
+    assertSame "test1" $(basename "$VIRTUAL_ENV")
+}
+
+test_workon_dot_with_space () {
+    cd $WORKON_HOME/" env with space"
+    workon .
+    assertTrue virtualenvwrapper_verify_active_environment
+    env_name=$(basename "$VIRTUAL_ENV")
+    assertSame " env with space" "$env_name"
+}
+
+test_workon_with_space () {
+    workon " env with space"
+    assertTrue virtualenvwrapper_verify_active_environment
+    env_name=$(basename "$VIRTUAL_ENV")
+    assertSame " env with space" "$env_name"
+}
+
 . "$test_dir/shunit2"
